@@ -51,9 +51,6 @@ GMount * nautilus_get_mounted_mount_for_root         (GFile *location);
 gboolean nautilus_should_use_templates_directory     (void);
 char *   nautilus_get_templates_directory            (void);
 char *   nautilus_get_templates_directory_uri        (void);
-void     nautilus_create_templates_directory         (void);
-
-char *   nautilus_get_searches_directory             (void);
 
 char *	 nautilus_compute_title_for_location	     (GFile *file);
 
