@@ -28,6 +28,8 @@
 #include "nautilus-directory-private.h"
 #include "nautilus-file.h"
 #include "nautilus-ui-utilities.h"
+#define DEBUG_FLAG NAUTILUS_DEBUG_SEARCH
+#include "nautilus-debug.h"
 
 #include <string.h>
 #include <glib.h>
@@ -77,7 +79,10 @@ finalize (GObject *object)
 static gboolean
 search_finished (NautilusSearchEngineModel *model)
 {
+        model->details->finished_id = 0;
+
 	if (model->details->hits != NULL) {
+	        DEBUG ("Model engine hits added");
 		nautilus_search_provider_hits_added (NAUTILUS_SEARCH_PROVIDER (model),
 						     model->details->hits);
 		g_list_free_full (model->details->hits, g_object_unref);
@@ -85,7 +90,9 @@ search_finished (NautilusSearchEngineModel *model)
 	}
 
 	model->details->query_pending = FALSE;
-	nautilus_search_provider_finished (NAUTILUS_SEARCH_PROVIDER (model));
+	DEBUG ("Model engine finished");
+	nautilus_search_provider_finished (NAUTILUS_SEARCH_PROVIDER (model),
+                                           NAUTILUS_SEARCH_PROVIDER_STATUS_NORMAL);
 	g_object_unref (model);
 
 	return FALSE;
@@ -165,6 +172,8 @@ nautilus_search_engine_model_start (NautilusSearchProvider *provider)
 		return;
 	}
 
+	DEBUG ("Model engine start");
+
 	g_object_ref (model);
 	model->details->query_pending = TRUE;
 
@@ -186,6 +195,8 @@ nautilus_search_engine_model_stop (NautilusSearchProvider *provider)
 	model = NAUTILUS_SEARCH_ENGINE_MODEL (provider);
 
 	if (model->details->query_pending) {
+	        DEBUG ("Model engine stop");
+
 		nautilus_directory_cancel_callback (model->details->directory,
 						    model_directory_ready_cb, model);
 		search_finished_idle (model);
