@@ -42,12 +42,18 @@ enum {
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL };
 
 G_DEFINE_TYPE_WITH_PRIVATE (NautilusProgressInfoWidget, nautilus_progress_info_widget,
-                            GTK_TYPE_BOX);
+                            GTK_TYPE_GRID);
 
 static void
 info_finished (NautilusProgressInfoWidget *self)
 {
-	gtk_widget_destroy (GTK_WIDGET (self));
+  	gtk_widget_set_sensitive (self->priv->cancel, FALSE);
+}
+
+static void
+info_cancelled (NautilusProgressInfoWidget *self)
+{
+  	gtk_widget_set_sensitive (self->priv->cancel, FALSE);
 }
 
 static void
@@ -85,7 +91,6 @@ cancel_clicked (GtkWidget *button,
 		NautilusProgressInfoWidget *self)
 {
 	nautilus_progress_info_cancel (self->priv->info);
-	gtk_widget_set_sensitive (button, FALSE);
 }
 
 static void
@@ -93,6 +98,9 @@ nautilus_progress_info_widget_dispose (GObject *obj)
 {
 	NautilusProgressInfoWidget *self = NAUTILUS_PROGRESS_INFO_WIDGET (obj);
 
+        if (self->priv->info != NULL) {
+                g_signal_handlers_disconnect_by_data (self->priv->info, self);
+        }
 	g_clear_object (&self->priv->info);
 
 	G_OBJECT_CLASS (nautilus_progress_info_widget_parent_class)->dispose (obj);
@@ -114,6 +122,9 @@ nautilus_progress_info_widget_constructed (GObject *obj)
 	g_signal_connect_swapped (self->priv->info,
 				  "finished",
 				  G_CALLBACK (info_finished), self);
+	g_signal_connect_swapped (self->priv->info,
+				  "cancelled",
+				  G_CALLBACK (info_cancelled), self);
 
 	update_data (self);
 	update_progress (self);
@@ -183,10 +194,15 @@ nautilus_progress_info_widget_class_init (NautilusProgressInfoWidgetClass *klass
 GtkWidget *
 nautilus_progress_info_widget_new (NautilusProgressInfo *info)
 {
-	return g_object_new (NAUTILUS_TYPE_PROGRESS_INFO_WIDGET,
+        NautilusProgressInfoWidget *self;
+
+	self = g_object_new (NAUTILUS_TYPE_PROGRESS_INFO_WIDGET,
 			     "info", info,
-			     "orientation", GTK_ORIENTATION_VERTICAL,
-			     "homogeneous", FALSE,
-			     "spacing", 5,
 			     NULL);
+
+        gtk_widget_set_sensitive (self->priv->cancel,
+                                  !nautilus_progress_info_get_is_finished (self->priv->info) &&
+                                  !nautilus_progress_info_get_is_cancelled (self->priv->info));
+
+        return GTK_WIDGET (self);
 }
